4.1. umbra.components.addons.projectsExplorer.models — Umbra 1.0.9 documentation

# 4.1. umbra.components.addons.projectsExplorer.models

models.py

Platform:
  Windows, Linux, Mac Os X.
Description:
  Defines the `umbra.components.factory.projectsExplorer.projectsExplorer.ProjectsExplorer` Component Interface class Models.

Others:

## 4.1.1. Module Attributes

`umbra.components.addons.projectsExplorer.models.` `LOGGER`

## 4.1.2. Classes

class `umbra.components.addons.projectsExplorer.models.` `ProjectsProxyModel`(parent, *args, **kwargs)

  Bases: `PyQt4.QtGui.QSortFilterProxyModel`

  Defines the proxy Model used by the `umbra.components.factory.projectsExplorer.projectsExplorer.ProjectsExplorer` Component Interface class.

  Initializes the class.

  Parameters: | parent (QObject) – Object parent. *args (*) – Arguments. **kwargs (**) – Keywords arguments.

  `filterAcceptsRow`(row, parent)

    Reimplements the `QSortFilterProxyModel.filterAcceptsRow()` method.

    Parameters: | row (int) – Source row. parent (QModelIndex) – Source parent.
    Returns: | Filter result
    Return type: | bool

  `data`(index, role=0)

    Reimplements the `QSortFilterProxyModel.data()` method.

    Parameters: | index (QModelIndex) – Index. role (int) – Role.
    Returns: | Data.
    Return type: | QVariant

  `getNode`(index)

    Returns the Node at given index.

    Parameters: | index (QModelIndex) – Index.
    Returns: | Node.
    Return type: | AbstractCompositeNode

  `getAttribute`(*args)

    Reimplements requisite method.